@@ -23,7 +23,7 @@ class KuroCommand():
             return (STX + '**'+ self.cmd + self.params + ETX).encode('utf8')
     
     def process_response(self, response_str):
-        print("kurocommand" + response_str)
+        logging.debug("kurocommand response" + response_str)
         if "ERR" in response_str:
             self.response_type = ResponseType.ERROR
         elif "XXX" in response_str:
@@ -41,7 +41,6 @@ class ParameterCommand(KuroCommand):
 
     def process_response(self, response_str):
         super().process_response(response_str)
-        print(self.response_type)
         if self.response_type == ResponseType.SUCCESS:
             self.response = self.params
         elif self.response_type == ResponseType.NOT_PROCESSED:
@@ -50,7 +49,7 @@ class ParameterCommand(KuroCommand):
         else:
             self.response = None
         logging.debug("response" + str(self.response))
-        print("response" + str(self.response))
+
 
 class OsdState(Enum):
     NONE = None
@@ -91,9 +90,11 @@ class VolCommand(KuroCommand):
     def process_response(self, response_str):
         super().process_response(response_str)
         if self.response_type == ResponseType.NOT_PROCESSED and self.params == None:
-            self.volume = int(response_str[-3:])
+            idx = response_str.find(self.cmd) + len(self.cmd)
+            response = response_str[idx:idx + 3]
+            self.volume = int(response)
         else:
-            self.response = None   
+            self.valume = None   
 
 class MutedState(Enum):
     NONE = None
@@ -132,6 +133,9 @@ class InputType(Enum):
     TERRESTRIAL = "82"
     DIGITAL = "83"
     HOME_MEDIA_GALLERY = "88"
+    
+    def describe(self):
+        return str(self.name).replace( "_"," ").title()
 
 class TunerType(Enum):
     NONE = None
@@ -205,12 +209,15 @@ class AVSType(Enum):
 
 class AVSCommand(ParameterCommand):
 
-    def __init__(self, screenMode = AVSType.NONE):
-        super().__init__("AVS", AVSType.value)
+    def __init__(self, avsType = AVSType.NONE):
+        super().__init__("AVS", avsType.value)
 
     def process_response(self, response):
         super().process_response(response)
-        self.avsType = AVSType(self.response[1:])
+        if self.response_type == ResponseType.SUCCESS and self.params == None:
+            self.avsType = AVSType.NONE
+        else:
+            self.avsType = AVSType(self.response[1:])
 
 
 class ScreenMode(Enum):
@@ -233,7 +240,10 @@ class ScreenModeCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        self.screenMode = ScreenMode(self.response[1:])
+        if self.response_type == ResponseType.SUCCESS and self.params == None:
+            self.screenMode = ScreenMode.NONE
+        else:
+            self.screenMode = ScreenMode(self.response[1:])
 
 
 class RemoteCommandType(Enum):
@@ -286,12 +296,13 @@ class PictureOffStatus(Enum):
 
 class PictureOffCommand(ParameterCommand):
 
-    def __init__(self, picture_off_status = PictureOffStatus.NONE)
+    def __init__(self, picture_off_status = PictureOffStatus.NONE):
         super().__init__("VMT", picture_off_status.value)
 
-    def process_response(self, response):
-        super().process_response(response)
-        if self.response_type == ResponseType.SUCCESS and self.params == None:
-            self.input_type = PictureOffStatus.NONE
-        else:
-            self.is_muted = PictureOffStatus(self.response[1:])
+    # def process_response(self, response):
+    #     super().process_response(response)
+    #     if (self.response_type == ResponseType.SUCCESS 
+    #     and self.params == None )  or self.response_type == ResponseType.ERROR:
+    #         self.is_muted = PictureOffStatus.NONE
+    #     else:
+    #         self.is_muted = PictureOffStatus(self.response[1:])
